@@ -21,9 +21,11 @@
 #   Boston, MA 02110-1301 USA
 # 
 
+import iso8601
+
 class Event:
 	def __init__(self, title, where, descr, start_time, end_time, \
-			full_day, id, cdate):
+			full_day, id, cdate, rrule=""):
 		self.title = title
 		self.where = where
 		self.descr = descr
@@ -33,6 +35,7 @@ class Event:
 		self.cdate = cdate
 		self.id = id
 		self.tzOffset = 0
+		self.rrule = rrule
 
 	def set_tzOffset(self, o):
 		self.tzOffset = o
@@ -74,3 +77,57 @@ class Event:
 
 	def get_cdate(self):
 		return int(self.cdate)
+
+	def get_until(self):
+		if self.rrule == "":
+			return -1
+
+		rules = self.rrule.split(";")
+		d = ""
+		for r in rules:
+			if r.startswith("UNTIL="):
+				d = r[len("UNTIL="):]
+
+		if len(d) == 8:
+			iso_date = d[:4] + "-" + d[4:6] + "-" + d[6:]
+		else:
+			iso_date = d[:4] + "-" + d[4:6] + "-" + d[6:11] \
+					+ ":" + d[11:13] + ":" + d[13:]
+
+		# ??
+		return int(iso8601.parse(iso_date)) + 1
+
+	def get_rrule(self):
+		return self.rrule
+
+	def get_rtype(self):
+		if self.rrule.find("YEARLY") <> -1:
+			return 5
+		elif self.rrule.find("MONTHLY") <> -1:
+			return 4
+		elif self.rrule.find("DAILY") <> -1:
+			return 1
+		elif self.rrule.find("WEEKLY") <> -1:
+			# look if all weekdays are listed:
+			start = self.rrule.find("BYDAY=")
+			end1 = self.rrule.find(";", start)
+			end2 = self.rrule.find("!", start) 
+			days = self.rrule[start+len(self.rrule):min(end1,end2)]
+			days_a = days.split(",")
+
+			if len(days_a) <> 5:
+				return 3
+			else:
+				if days_a.count("MO") and days_a.count("TU") \
+						and days_a.count("WE") \
+						and days_a.count("TH") \
+						and days_a.count("FR"):
+
+							return 2
+				else:
+					return 3
+
+
+		else:
+			return 0
+
