@@ -14,7 +14,4 @@ def getAllLocalCalendars():
 
 def add_local_calendar(cal_name):
 	last_id = cwrapper.createLocalCalendar(cal_name)
-	if last_id == -1:
-		return False
-	else:
-		return True
+	return last_id
